!======================================================================!
      Subroutine basesph(lpr)
!======================================================================!
!
!     determines the basis for Dirac equation in spherical coordinates
!
!     NBSP        number of K-parity-blocks
!     abs(KB)   K-quantum number of each block (K+1/2)
!     sign(KB)  parity of each block ( +1 or  -)
!     IASP(ib,1): begin of the large components of block b is IASP(b,1)+1 
!     IASP(ib,2): begin of the small components of block b is IASP(b,2)+1 
!     IDSP(ib,1): dimension large components of block b 
!     IDSP(ib,2): dimension small components of block b 
!----------------------------------------------------------------------!
! Use Definitions
! Use MeanField

      implicit real*8 (a-h,o-z)
      include 'dirhb.par'

!      Implicit None
!
      Logical lpr
      Integer nps(nt2x)
      Integer ipar(2),ntsp,nksp
      Integer nrm,nlm,njm,nmm,nfx0,ngx0,il,ik,n0f,ip,ib,im
      Integer ipf,nl1,nr1,nj1,nm1,nn1,mf,ifg!,mg
      Integer i,nbsp,nf,ng,nh

      common/basesph1/nljm(nt2x,4),idsp(2,2),iasp(2,2)

      data ipar/1,2/

      if (lpr) write(l6,*) ' ****** BEGIN Sph.BASE *************'
!
      n0f = n0fx
!======================================================================!
!     Spherical Oscillator-Base for Fermions:
!======================================================================!
!----------------------------------------------------------------------!
!     Construction of the different Parity blocks.
!----------------------------------------------------------------------!
      nbsp  = 2
      nrm = 0
      nlm = 0
      njm = 0
      nmm = 0
      nfx0 = 0
      ngx0 = 0
!
      il = 0
      ik = 0
!
!---------loop over parity block
       do  ib = 1,nbsp
           ipf = ipar(ib)  !ipf=ib (parity)
!        mu(ib) = 1
!
!           write(tb(ib),'(a1)') tp(ipf)
!
! --------loop over large and small components
           write(*,*) 'nf=',n0f
           do ifg = 1,2
              iasp(ib,ifg) = il
              if (ifg.eq.1) then
                 ip = ipf
              else
                 ip = 3 - ipf
              endif
!-----------------------------
      do nn1=ip-1,n0f+ifg-1,2   !loop over major quantum number N.

         do nr1=1,nn1/2+1        !loop over radial quantum number nr.

             do nl1=0,nn1        !loop over orbital angular momentum l.
       
             if(2*(nr1-1)+nl1.ne.nn1) goto 10

!             do ms=0,1         ! ms=0 spin para. orbit. and ms=1 spin anti-para.
!                nj=nl+1-ms     ! nj=j+1/2=(l+/-1/2+1/2)=nl+1 or nl
             do nj1=nl1,nl1+1

              do nm1=-nj1+1,nj1     !magnetic quantum number m_j

               il=il+1
               if(il.gt.nt2x) then
                   write(*,*) 'il1=',il  
                   stop 'in BASE : ntx too small'
               endif
               nljm(il,1)=nr1
               nljm(il,2)=nl1
               nljm(il,3)=nj1
               nljm(il,4)=nm1
               im  =  nljm(il,4)
               nps(il)    = ifg
!
!               if (nn1.lt.10) then
!                 write(tts(il),333) nr1,tl(nl1),nj1+nj1-1,2*nm1-1,tp(ip)
!               else
!                 write(tts(il),334) nr1,tl(nl1),nj1+nj1-1,2*nm1-1 
!               endif
!
c               if (nn1.lt.10) then
c                 write(tts(il),333) nr1,tl(nl1),nj1+nj1-1,2*nm1-1,tp(ip)
c               else
c                 write(tts(il),334) nr1,tl(nl1),nj1+nj1-1,2*nm1-1 ! ,tp(ip)
c               endif
333            format(i2,a1,i2,2h/2,i3,2h/2,a)
334            format(i2,a1,i2,2h/2,i3,2h/2)
               nrm = max0(nrm,nr1)
               nlm = max0(nlm,nl1)
               njm = max0(njm,nj1)
               nmm = max0(nmm,nm1)
          enddo !nm
          enddo !nj
   10     enddo !nl
      enddo !nr
      enddo !nn
!
      idsp(ib,ifg) = il - iasp(ib,ifg)
      enddo   ! ifg
      nfx0 = max(nfx0,idsp(ib,1))
      ngx0 = max(ngx0,idsp(ib,2))
      ik = ik + max0(idsp(ib,1),idsp(ib,2))
!
      enddo   ! ib
      ntsp = il
      nksp = ik
!      if (nrm.gt.nmax)   stop 'in BASE: nmax too small '
!      if (nlm.gt.nmax)   stop 'in BASE: nmax too small '
!      if (njm.gt.nmax)   stop 'in BASE: nmax too small '
!      if (nmm.gt.nma2x)  stop 'in BASE: nmax too small '

!
!          
      if (lpr) then
         write(l6,*) ' '
         write(l6,*)   'Maximal values:                   needed   
     &  given'
         write(l6,103) ' Number of levels  ntsp= ',ntsp,nt2x 
         write(l6,103) ' Number of levels  nbsp= ',nbsp,nbspx 
         write(l6,103) ' Number of levels  nksp= ',nksp,nk2x 
         write(l6,103) ' Maximal nr:       nrm = ',nrm,ntx
         write(l6,103) ' Maximal nl:       nlm = ',nlm,ntx
         write(l6,103) ' Maximal nj:       njm = ',njm,ntx
         write(l6,103) ' Maximal nm:       nmm = ',nmm,ntx
         write(l6,103) ' Maximal nf            = ',nfx0,nfspx
         write(l6,103) ' Maximal ng            = ',ngx0,ngspx
      endif
!
!----------------------------------------------------------------------!
!----------------------------------------------------------------------!
!     Printout
!----------------------------------------------------------------------!
      if (lpr) then
         do ib = 1,nbsp
        nf  = idsp(ib,1)
        ng  = idsp(ib,2)
        nh  = nf + ng
        mf  = iasp(ib,1)
c        mg  = iasp(ib,2)
c            write(l6,'(/,i3,a,6i6)') ib,tb(ib),nf,ng,mf,mg
            do i = mf+1,mf+nh
               write(l6,102) i,'   nr = ',nljm(i,1),
     &                         '   nl = ',nljm(i,2),
     &                         '   nj = ',nljm(i,3),
     &                         '   nm = ',nljm(i,4) ! ,tts(i)
           if (i.eq.mf+nf) write(l6,'(3x,61(1h-))')
            enddo  ! i
         enddo   ! ib
      endif
!
  100 format(1h[,4i2,1h],a)
  101 format(4i2)
  102 format(i4,a,i2,a,i2,a,i2,a,i3,a,i3) 
  103 format(a,2i15)
!    
      if (lpr) 
     &write(l6,*) ' ****** END Spherical BASE ***********************'
!      stop 'final stop in BASE'
! 
      return
!-end-BASE
      end
!======================================================================!
